# -*- coding: utf-8 -*-

# DO NOT EDIT THIS FILE!
# This file has been autogenerated by dephell <3
# https://github.com/dephell/dephell

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import os.path

readme = ''
here = os.path.abspath(os.path.dirname(__file__))
readme_path = os.path.join(here, 'README.rst')
if os.path.exists(readme_path):
    with open(readme_path, 'rb') as stream:
        readme = stream.read().decode('utf8')

setup(
    long_description=readme,
    name='django-admin-urls',
    version='0.3.1',
    description='Django admin url shortcuts',
    python_requires='>=3.6',
    project_urls={
        "repository": "https://gitlab.com/cyberbudy/django-admin-urls/"
    },
    author='Alex Uzjakov',
    author_email='cyberbudy@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta', 'Programming Language :: Python :: 3',
        'Framework :: Django', 'Intended Audience :: Developers',
        'Topic :: Utilities', 'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ],
    packages=['dj_admin_urls'],
    package_dir={"": "."},
    package_data={},
    install_requires=['django>=3.0.0'],
)
